BookingDatePicker class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BookingDatePicker
Constructors
-
BookingDatePicker({Key? key, required ValueChanged<
DateTime> onChanged, CustomButtonStyle? buttonStyle, TextStyle? weekDayStyle = const TextStyle(fontWeight: FontWeight.bold), Icon seekIcon = const Icon(Icons.arrow_back_ios), Icon previousIcon = const Icon(Icons.arrow_forward_ios_sharp), double? height, double width = 400, TextStyle? monthStyle = const TextStyle(fontWeight: FontWeight.bold), String locale = "en_EN", Color selectItemColor = Colors.green, Color itemColor = Colors.white, Color itemBorderColor = Colors.grey, double itemRadius = 12, double borderRadius = 12}) -
const
Properties
- borderRadius → double
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- itemBorderColor → Color
-
final
- itemColor → Color
-
final
- itemRadius → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → String
-
final
- monthStyle → TextStyle?
-
final
-
onChanged
→ ValueChanged<
DateTime> -
final
- previousIcon → Icon
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seekIcon → Icon
-
final
- selectItemColor → Color
-
final
- weekDayStyle → TextStyle?
-
final
- width → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BookingDatePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited