CustomButtonStyle class

Constructors

CustomButtonStyle({String title = "Select", Color color = Colors.black, double? width, double height = 45, TextStyle textStyle = const TextStyle(color: Colors.white)})

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final
title String
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited